@@ -72,11 +72,11 @@ def get_tools(tools_list: list, alita_client, llm, memory_store: BaseStore = Non
                 bucket=tool['settings']['bucket'],
                 toolkit_name=tool.get('toolkit_name', ''),
                 selected_tools=tool['settings'].get('selected_tools', []),
-                llm=tool['settings'].get('llm'),
+                llm=llm,
                 # indexer settings
                 connection_string=tool['settings'].get('connection_string', None),
-                collection_name=f"{tool.get('toolkit_name')}_{str(tool['id'])}",
-                embedding_model=tool['settings'].get('embedding_model', None),
+                collection_name=tool.get('toolkit_name'),
+                embedding_model=tool['settings'].get('embedding_model'),
                 embedding_model_params=tool['settings'].get('embedding_model_params', None),
                 vectorstore_type="PGVector"
             ).get_tools())
