@@ -1,5 +1,6 @@
 import hashlib
 import json
+import logging
 from typing import Any, Optional, Generator, List
 
 from langchain_core.documents import Document
@@ -8,24 +9,18 @@ from pydantic import create_model, Field, model_validator
 
 from alita_sdk.tools.elitea_base import BaseVectorStoreToolApiWrapper, extend_with_vector_tools
 
-try:
-    from alita_sdk.runtime.langchain.interfaces.llm_processor import get_embeddings
-except ImportError:
-    from alita_sdk.langchain.interfaces.llm_processor import get_embeddings
-
 class ArtifactWrapper(BaseVectorStoreToolApiWrapper):
-    client: Any
     bucket: str
     artifact: Optional[Any] = None
     
     @model_validator(mode='before')
     @classmethod
     def validate_toolkit(cls, values):
-        if not values.get('client'):
+        if not values.get('alita'):
             raise ValueError("Client is required.")
         if not values.get('bucket'):
             raise ValueError("Bucket is required.")
-        values["artifact"] = values['client'].artifact(values['bucket'])
+        values["artifact"] = values['alita'].artifact(values['bucket'])
         return values
 
     def list_files(self, bucket_name = None, return_as_string = True):
@@ -82,7 +77,10 @@ class ArtifactWrapper(BaseVectorStoreToolApiWrapper):
         return hasher.hexdigest()
 
     def _process_document(self, document: Document) -> Generator[Document, None, None]:
-        page_content = self.read_file(document.metadata['name'], is_capture_image=True, excel_by_sheets=True)
+        try:
+            page_content = self.read_file(document.metadata['name'], is_capture_image=True, excel_by_sheets=True)
+        except Exception as e:
+            logging.error(f"Failed while parsing the file 'document.metadata['Path']': {e}")
         if isinstance(page_content, dict):
             for key, value in page_content.items():
                 metadata = document.metadata
@@ -90,7 +88,6 @@ class ArtifactWrapper(BaseVectorStoreToolApiWrapper):
                 yield Document(page_content=str(value), metadata=metadata)
         else:
             document.page_content = json.dumps(str(page_content))
-            yield document
 
     @extend_with_vector_tools
     def get_available_tools(self):
