@@ -1,4 +1,5 @@
 import logging
+from copy import deepcopy
 from importlib import import_module
 from typing import Optional
 
@@ -80,6 +81,7 @@ _safe_import_tool('pptx', 'pptx', 'get_tools', 'PPTXToolkit')
 _safe_import_tool('postman', 'postman', 'get_tools', 'PostmanToolkit')
 _safe_import_tool('memory', 'memory', 'get_tools', 'MemoryToolkit')
 _safe_import_tool('zephyr_squad', 'zephyr_squad', 'get_tools', 'ZephyrSquadToolkit')
+_safe_import_tool('zephyr_essential', 'zephyr_essential', 'get_tools', 'ZephyrEssentialToolkit')
 _safe_import_tool('slack', 'slack', 'get_tools', 'SlackToolkit')
 _safe_import_tool('bigquery', 'google.bigquery', 'get_tools', 'BigQueryToolkit')
 _safe_import_tool('delta_lake', 'aws.delta_lake', 'get_tools', 'DeltaLakeToolkit')
@@ -176,6 +178,10 @@ def get_available_toolkits():
     """Return list of available toolkit class names."""
     return list(AVAILABLE_TOOLKITS.keys())
 
+def get_available_toolkit_models():
+    """Return dict with available toolkit classes."""
+    return deepcopy(AVAILABLE_TOOLS)
+
 def diagnose_imports():
     """Print diagnostic information about tool imports."""
     available_count = len(AVAILABLE_TOOLS)
@@ -215,5 +221,6 @@ __all__ = [
     'get_available_tools',
     'get_failed_imports',
     'get_available_toolkits',
+    'get_available_toolkit_models',
     'diagnose_imports'
 ]
