@@ -1,9 +1,11 @@
 from typing import List, Optional, Literal
 
 from langchain_core.tools import BaseTool, BaseToolkit
-from pydantic import create_model, BaseModel, Field, SecretStr
+from pydantic import create_model, BaseModel, Field
 
 import requests
+from ....configurations.ado import AdoConfiguration
+from ....configurations.pgvector import PgVectorConfiguration
 from .test_plan_wrapper import TestPlanApiWrapper
 from ...base.tool import BaseAction
 from ...utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length, check_connection_response
@@ -24,15 +26,13 @@ class AzureDevOpsPlansToolkit(BaseToolkit):
         m = create_model(
             name_alias,
             name=(str, Field(description="Toolkit name", json_schema_extra={'toolkit_name': True, 'max_toolkit_length': AzureDevOpsPlansToolkit.toolkit_max_length})),
-            organization_url=(str, Field(title="Organization URL",
-                                                   description="ADO organization url",
-                                                   json_schema_extra={
-                                                       'configuration': True,
-                                                       'configuration_title': True
-                                                   })),
-            project=(str, Field(title="Project", description="ADO project", json_schema_extra={'configuration': True})),
+            ado_configuration=(AdoConfiguration, Field(description="Ado configuration", json_schema_extra={'configuration_types': ['ado']})),
             limit=(Optional[int], Field(description="ADO plans limit used for limitation of the list with results", default=5)),
-            token=(SecretStr, Field(description="ADO token", json_schema_extra={'secret': True, 'configuration': True})),
+            # indexer settings
+            pgvector_configuration=(Optional[PgVectorConfiguration], Field(default=None,
+                                                                           description="PgVector Configuration", json_schema_extra={'configuration_types': ['pgvector']})),
+            # embedder settings
+            embedding_model=(Optional[str], Field(default=None, description="Embedding configuration.", json_schema_extra={'configuration_model': 'embedding'})),
             selected_tools=(List[Literal[tuple(selected_tools)]], Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             __config__={'json_schema_extra': {'metadata':
                 {
@@ -65,9 +65,12 @@ class AzureDevOpsPlansToolkit(BaseToolkit):
 
         @check_connection_response
         def check_connection(self):
+            ado_config = self.ado_test_plan_configuration.ado_configuration if self.ado_test_plan_configuration else None
+            if not ado_config:
+                raise ValueError("ADO test plan configuration is required")
             response = requests.get(
-                f'{self.organization_url}/{self.project}/_apis/testplan/plans?api-version=7.0',
-                headers = {'Authorization': f'Bearer {self.token}'},
+                f'{ado_config.organization_url}/{ado_config.project}/_apis/testplan/plans?api-version=7.0',
+                headers = {'Authorization': f'Bearer {ado_config.token}'},
                 timeout=5
             )
             return response
@@ -82,7 +85,13 @@ class AzureDevOpsPlansToolkit(BaseToolkit):
             environ['AZURE_DEVOPS_CACHE_DIR'] = '/tmp/.azure-devops'
         if selected_tools is None:
             selected_tools = []
-        azure_devops_api_wrapper = TestPlanApiWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # TODO use ado_configuration fields in TestPlanApiWrapper
+            **kwargs['ado_configuration'],
+            **(kwargs.get('pgvector_configuration') or {}),
+        }
+        azure_devops_api_wrapper = TestPlanApiWrapper(**wrapper_payload)
         available_tools = azure_devops_api_wrapper.get_available_tools()
         tools = []
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
