@@ -16,11 +16,6 @@ from pydantic.fields import FieldInfo as Field
 from ..work_item import AzureDevOpsApiWrapper
 from ...elitea_base import BaseVectorStoreToolApiWrapper, extend_with_vector_tools
 
-try:
-    from alita_sdk.runtime.langchain.interfaces.llm_processor import get_embeddings
-except ImportError:
-    from alita_sdk.langchain.interfaces.llm_processor import get_embeddings
-
 logger = logging.getLogger(__name__)
 
 # Input models for Test Plan operations
@@ -164,6 +159,7 @@ TestCasesGetModel = create_model(
 )
 
 class TestPlanApiWrapper(BaseVectorStoreToolApiWrapper):
+    # TODO use ado_configuration instead of organization_url, project and token
     __test__ = False
     organization_url: str
     project: str
@@ -364,7 +360,7 @@ class TestPlanApiWrapper(BaseVectorStoreToolApiWrapper):
             logger.error(f"Error getting test cases: {e}")
             return ToolException(f"Error getting test cases: {e}")
 
-    def _base_loader(self, plan_id: str, suite_ids: Optional[list[str]] = []) -> Generator[Document, None, None]:
+    def _base_loader(self, plan_id: str, suite_ids: Optional[list[str]] = [], **kwargs) -> Generator[Document, None, None]:
         cases = []
         for sid in suite_ids:
             cases.extend(self.get_test_cases(plan_id, sid))
