@@ -1,3 +1,4 @@
+import hashlib
 import logging
 from typing import Any, Dict, Generator, Optional
 
@@ -16,11 +17,6 @@ from pydantic.fields import Field
 
 from ...elitea_base import BaseVectorStoreToolApiWrapper, extend_with_vector_tools
 
-try:
-    from alita_sdk.runtime.langchain.interfaces.llm_processor import get_embeddings
-except ImportError:
-    from alita_sdk.langchain.interfaces.llm_processor import get_embeddings
-
 logger = logging.getLogger(__name__)
 
 GetWikiInput = create_model(
@@ -60,19 +56,13 @@ RenamePageInput = create_model(
 
 
 class AzureDevOpsApiWrapper(BaseVectorStoreToolApiWrapper):
+    # TODO use ado_configuration instead of organization_url, project and token
     organization_url: str
     project: str
     token: SecretStr
     _client: Optional[WikiClient] = PrivateAttr()  # Private attribute for the wiki client
     _core_client: Optional[CoreClient] = PrivateAttr()  # Private attribute for the CoreClient client
 
-    llm: Any = None
-    connection_string: Optional[SecretStr] = None
-    collection_name: Optional[str] = None
-    embedding_model: Optional[str] = "HuggingFaceEmbeddings"
-    embedding_model_params: Optional[Dict[str, Any]] = {"model_name": "sentence-transformers/all-MiniLM-L6-v2"}
-    vectorstore_type: Optional[str] = "PGVector"
-
     class Config:
         arbitrary_types_allowed = True  # Allow arbitrary types (e.g., WorkItemTrackingClient)
 
@@ -229,21 +219,26 @@ class AzureDevOpsApiWrapper(BaseVectorStoreToolApiWrapper):
             logger.error(f"Unable to modify wiki page: {str(e)}")
             return ToolException(f"Unable to modify wiki page: {str(e)}")
 
-    def _base_loader(self, wiki_identifier: str) -> Generator[Document, None, None]:
+    def _base_loader(self, wiki_identifier: str, title_contains: Optional[str] = None, **kwargs) -> Generator[Document, None, None]:
         pages = self._client.get_pages_batch(pages_batch_request={}, project=self.project, wiki_identifier=wiki_identifier)
         #
         for page in pages:
             content = self._client.get_page_by_id(project=self.project, wiki_identifier=wiki_identifier, id=page.id, include_content=True).page.content
-            yield Document(page_content=content, metadata={
-                'id': page.id, 
-                'path': page.path,
-                'updated_on': ''
-            })
+            content_hash = hashlib.sha256(content.encode("utf-8")).hexdigest()
+            title = page.path.rsplit("/", 1)[-1]
+            if not title_contains or (title_contains and title_contains.lower() in title.lower()):
+                yield Document(page_content=content, metadata={
+                    'id': str(page.id),
+                    'path': page.path,
+                    'title': title,
+                    'updated_on': content_hash
+                })
 
     def _index_tool_params(self):
         """Return the parameters for indexing data."""
         return {
-            "wiki_identifier": (str, Field(description="Wiki identifier to index, e.g., 'ABCProject.wiki'"))
+            "wiki_identifier": (str, Field(description="Wiki identifier to index, e.g., 'ABCProject.wiki'")),
+            'title_contains': (Optional[str], Field(default=None, description="Optional filter to include only pages with titles containing exact this string"))
         }
 
     @extend_with_vector_tools
