@@ -3,7 +3,6 @@ import logging
 import urllib.parse
 from typing import Dict, List, Generator, Optional
 
-from alita_sdk.tools.elitea_base import BaseVectorStoreToolApiWrapper, extend_with_vector_tools
 from azure.devops.connection import Connection
 from azure.devops.v7_1.core import CoreClient
 from azure.devops.v7_1.wiki import WikiClient
@@ -15,10 +14,7 @@ from pydantic import create_model, PrivateAttr, SecretStr
 from pydantic import model_validator
 from pydantic.fields import Field
 
-try:
-    from alita_sdk.runtime.langchain.interfaces.llm_processor import get_embeddings
-except ImportError:
-    from alita_sdk.langchain.interfaces.llm_processor import get_embeddings
+from alita_sdk.tools.non_code_indexer_toolkit import NonCodeIndexerToolkit
 
 logger = logging.getLogger(__name__)
 
@@ -94,7 +90,8 @@ ADOUnlinkWorkItemsFromWikiPage = create_model(
     page_name=(str, Field(description="Wiki page path to unlink the work items from", examples=["/TargetPage"]))
 )
 
-class AzureDevOpsApiWrapper(BaseVectorStoreToolApiWrapper):
+class AzureDevOpsApiWrapper(NonCodeIndexerToolkit):
+    # TODO use ado_configuration instead of organization_url, project and token
     organization_url: str
     project: str
     token: SecretStr
@@ -124,7 +121,7 @@ class AzureDevOpsApiWrapper(BaseVectorStoreToolApiWrapper):
         except Exception as e:
             return ImportError(f"Failed to connect to Azure DevOps: {e}")
 
-        return values
+        return super().validate_toolkit(values)
 
     def _parse_work_items(self, work_items, fields=None):
         """Parse work items dynamically based on the fields requested."""
@@ -521,14 +518,14 @@ class AzureDevOpsApiWrapper(BaseVectorStoreToolApiWrapper):
                 'reason': wi.fields.get('System.Reason', ''),
                 'iteration': wi.fields.get('System.IterationPath', ''),
                 'updated_on': wi.fields.get('System.ChangedDate', ''),
-                'attachment_ids': [rel.url.split('/')[-1] for rel in wi.relations or [] if rel.rel == 'AttachedFile']
+                'attachment_ids': {rel.url.split('/')[-1]:rel.attributes.get('name', '') for rel in wi.relations or [] if rel.rel == 'AttachedFile'}
             })
 
     def _process_document(self, document: Document) -> Generator[Document, None, None]:
-        for attachment_id in document.metadata.get('attachment_ids', []):
+        for attachment_id, file_name in document.metadata.get('attachment_ids', {}).items():
             content_generator = self._client.get_attachment_content(id=attachment_id, download=True)
-            content = ''.join(str(item) for item in content_generator)
-            yield Document(page_content=content, metadata={'id': attachment_id})
+            content = b"".join(x for x in content_generator)
+            yield Document(page_content="", metadata={'id': attachment_id, 'loader_content_type': file_name, 'loader_content': content})
 
     def _index_tool_params(self):
         """Return the parameters for indexing data."""
@@ -536,10 +533,9 @@ class AzureDevOpsApiWrapper(BaseVectorStoreToolApiWrapper):
             "wiql": (str, Field(description="WIQL (Work Item Query Language) query string to select and filter Azure DevOps work items."))
         }
 
-    @extend_with_vector_tools
     def get_available_tools(self):
         """Return a list of available tools."""
-        return [
+        return super().get_available_tools() + [
             {
                 "name": "search_work_items",
                 "description": self.search_work_items.__doc__,
