@@ -6,8 +6,10 @@ from .api_wrapper import BitbucketAPIWrapper
 from .tools import __all__
 from langchain_core.tools import BaseToolkit
 from langchain_core.tools import BaseTool
-from pydantic import BaseModel, Field, ConfigDict, create_model, SecretStr
+from pydantic import BaseModel, Field, ConfigDict, create_model
 from ..utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length, check_connection_response
+from ...configurations.bitbucket import BitbucketConfiguration
+from ...configurations.pgvector import PgVectorConfiguration
 import requests
 
 
@@ -20,18 +22,15 @@ def get_tools(tool):
         url=tool['settings']['url'],
         project=tool['settings']['project'],
         repository=tool['settings']['repository'],
-        username=tool['settings']['username'],
-        password=tool['settings']['password'],
+        bitbucket_configuration=tool['settings']['bitbucket_configuration'],
         branch=tool['settings']['branch'],
         cloud=tool['settings'].get('cloud'),
         llm=tool['settings'].get('llm', None),
         alita=tool['settings'].get('alita', None),
-        connection_string=tool['settings'].get('connection_string', None),
-        collection_name=str(tool['id']),
+        pgvector_configuration=tool['settings'].get('pgvector_configuration', {}),
+        collection_name=str(tool['toolkit_name']),
         doctype='code',
-        embedding_model="HuggingFaceEmbeddings",
-        embedding_model_params={"model_name": "sentence-transformers/all-MiniLM-L6-v2"},
-        vectorstore_type="PGVector",
+        embedding_model=tool['settings'].get('embedding_model'),
         toolkit_name=tool.get('toolkit_name')
     ).get_tools()
 
@@ -49,17 +48,14 @@ class AlitaBitbucketToolkit(BaseToolkit):
         AlitaBitbucketToolkit.toolkit_max_length = get_max_toolkit_length(selected_tools)
         m = create_model(
             name,
-            url=(str, Field(description="Bitbucket URL", json_schema_extra={'configuration': True, 'configuration_title': True})),
             project=(str, Field(description="Project/Workspace", json_schema_extra={'configuration': True})),
             repository=(str, Field(description="Repository", json_schema_extra={'max_toolkit_length': AlitaBitbucketToolkit.toolkit_max_length, 'configuration': True})),
             branch=(str, Field(description="Main branch", default="main")),
-            username=(str, Field(description="Username", json_schema_extra={'configuration': True})),
-            password=(SecretStr, Field(description="GitLab private token", json_schema_extra={'secret': True, 'configuration': True})),
             cloud=(Optional[bool], Field(description="Hosting Option", default=None)),
-            # indexer settings
-            connection_string=(Optional[SecretStr], Field(description="Connection string for vectorstore",
-                                                          default=None,
-                                                          json_schema_extra={'secret': True})),
+            bitbucket_configuration=(Optional[BitbucketConfiguration], Field(description="Bitbucket Configuration", json_schema_extra={'configuration_types': ['bitbucket']})),
+            pgvector_configuration=(Optional[PgVectorConfiguration], Field(default=None, description="PgVector Configuration", json_schema_extra={'configuration_types': ['pgvector']})),
+            # embedder settings
+            embedding_model=(Optional[str], Field(default=None, description="Embedding configuration.", json_schema_extra={'configuration_model': 'embedding'})),
             selected_tools=(List[Literal[tuple(selected_tools)]], Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             __config__=ConfigDict(json_schema_extra=
             {
@@ -74,11 +70,16 @@ class AlitaBitbucketToolkit(BaseToolkit):
 
         @check_connection_response
         def check_connection(self):
+            bitbucket_config = self.bitbucket_configuration or {}
+            url = bitbucket_config.get('url', '')
+            username = bitbucket_config.get('username', '')
+            password = bitbucket_config.get('password', '')
+
             if self.cloud:
-                request_url = f"{self.url}/2.0/repositories/{self.project}/{self.repository}"
+                request_url = f"{url}/2.0/repositories/{self.project}/{self.repository}"
             else:
-                request_url = f"{self.url}/rest/api/1.0/projects/{self.project}/repos/{self.repository}"
-            response = requests.get(request_url, auth=HTTPBasicAuth(self.username, self.password))
+                request_url = f"{url}/rest/api/1.0/projects/{self.project}/repos/{self.repository}"
+            response = requests.get(request_url, auth=HTTPBasicAuth(username, password))
             return response
 
         m.check_connection = check_connection
@@ -90,7 +91,13 @@ class AlitaBitbucketToolkit(BaseToolkit):
             selected_tools = []
         if kwargs["cloud"] is None:
             kwargs["cloud"] = True if "bitbucket.org" in kwargs.get('url') else False
-        bitbucket_api_wrapper = BitbucketAPIWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # TODO use bitbucket_configuration fields
+            **kwargs['bitbucket_configuration'],
+            **(kwargs.get('pgvector_configuration') or {}),
+        }
+        bitbucket_api_wrapper = BitbucketAPIWrapper(**wrapper_payload)
         available_tools: List[Dict] = __all__
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
         tools = []
