@@ -1,5 +1,6 @@
 import ast
 import fnmatch
+import json
 import logging
 import traceback
 from typing import Any, Optional, List, Literal, Dict, Generator
@@ -8,9 +9,10 @@ from langchain_core.documents import Document
 from langchain_core.tools import ToolException
 from pydantic import BaseModel, create_model, Field, SecretStr
 
-from alita_sdk.runtime.langchain.interfaces.llm_processor import get_embeddings
+# from alita_sdk.runtime.langchain.interfaces.llm_processor import get_embeddings
 from .chunkers import markdown_chunker
 from .utils import TOOLKIT_SPLITTER
+from .vector_adapters.VectorStoreAdapter import VectorStoreAdapterFactory
 from ..runtime.utils.utils import IndexerKeywords
 
 logger = logging.getLogger(__name__)
@@ -28,17 +30,16 @@ LoaderSchema = create_model(
 # Base Vector Store Schema Models
 BaseIndexParams = create_model(
     "BaseIndexParams",
-    collection_suffix=(Optional[str], Field(description="Optional suffix for collection name (max 7 characters)", default="", max_length=7)),
-    vectorstore_type=(Optional[str], Field(description="Vectorstore type (Chroma, PGVector, Elastic, etc.)", default="PGVector")),
+    collection_suffix=(str, Field(description="Suffix for collection name (max 7 characters) used to separate datasets", min_length=1, max_length=7)),
 )
 
 BaseCodeIndexParams = create_model(
     "BaseCodeIndexParams",
-    collection_suffix=(Optional[str], Field(description="Optional suffix for collection name (max 7 characters)", default="", max_length=7)),
-    vectorstore_type=(Optional[str], Field(description="Vectorstore type (Chroma, PGVector, Elastic, etc.)", default="PGVector")),
+    collection_suffix=(str, Field(description="Suffix for collection name (max 7 characters) used to separate datasets", min_length=1, max_length=7)),
     branch=(Optional[str], Field(description="Branch to index files from. Defaults to active branch if None.", default=None)),
-    whitelist=(Optional[List[str]], Field(description="File extensions or paths to include. Defaults to all files if None.", default=None)),
-    blacklist=(Optional[List[str]], Field(description="File extensions or paths to exclude. Defaults to no exclusions if None.", default=None)),
+    whitelist=(Optional[List[str]], Field(description='File extensions or paths to include. Defaults to all files if None. Example: ["*.md", "*.java"]', default=None)),
+    blacklist=(Optional[List[str]], Field(description='File extensions or paths to exclude. Defaults to no exclusions if None. Example: ["*.md", "*.java"]', default=None)),
+    clean_index=(Optional[bool], Field(default=False, description="Optional flag to enforce clean existing index before indexing new data")),
 )
 
 RemoveIndexParams = create_model(
@@ -49,40 +50,40 @@ RemoveIndexParams = create_model(
 BaseSearchParams = create_model(
     "BaseSearchParams",
     query=(str, Field(description="Query text to search in the index")),
-    collection_suffix=(Optional[str], Field(description="Optional suffix for collection name (max 7 characters)", default="", max_length=7)),
-    vectorstore_type=(Optional[str], Field(description="Vectorstore type (Chroma, PGVector, Elastic, etc.)", default="PGVector")),
-    filter=(Optional[dict | str], Field(
+    collection_suffix=(Optional[str], Field(
+        description="Optional suffix for collection name (max 7 characters). Leave empty to search across all datasets",
+        default="", max_length=7)),
+    filter=(Optional[dict], Field(
         description="Filter to apply to the search results. Can be a dictionary or a JSON string.",
         default={},
         examples=["{\"key\": \"value\"}", "{\"status\": \"active\"}"]
     )),
     cut_off=(Optional[float], Field(description="Cut-off score for search results", default=0.5)),
     search_top=(Optional[int], Field(description="Number of top results to return", default=10)),
-    reranker=(Optional[dict], Field(
-        description="Reranker configuration. Can be a dictionary with reranking parameters.",
-        default={}
-    )),
     full_text_search=(Optional[Dict[str, Any]], Field(
         description="Full text search parameters. Can be a dictionary with search options.",
         default=None
     )),
-    reranking_config=(Optional[Dict[str, Dict[str, Any]]], Field(
-        description="Reranking configuration. Can be a dictionary with reranking settings.",
-        default=None
-    )),
     extended_search=(Optional[List[str]], Field(
         description="List of additional fields to include in the search results.",
         default=None
     )),
+    reranker=(Optional[dict], Field(
+        description="Reranker configuration. Can be a dictionary with reranking parameters.",
+        default={}
+    )),
+    reranking_config=(Optional[Dict[str, Dict[str, Any]]], Field(
+        description="Reranking configuration. Can be a dictionary with reranking settings.",
+        default=None
+    )),
 )
 
 BaseStepbackSearchParams = create_model(
     "BaseStepbackSearchParams",
     query=(str, Field(description="Query text to search in the index")),
     collection_suffix=(Optional[str], Field(description="Optional suffix for collection name (max 7 characters)", default="", max_length=7)),
-    vectorstore_type=(Optional[str], Field(description="Vectorstore type (Chroma, PGVector, Elastic, etc.)", default="PGVector")),
     messages=(Optional[List], Field(description="Chat messages for stepback search context", default=[])),
-    filter=(Optional[dict | str], Field(
+    filter=(Optional[dict], Field(
         description="Filter to apply to the search results. Can be a dictionary or a JSON string.",
         default={},
         examples=["{\"key\": \"value\"}", "{\"status\": \"active\"}"]
@@ -110,11 +111,11 @@ BaseStepbackSearchParams = create_model(
 BaseIndexDataParams = create_model(
     "indexData",
     __base__=BaseIndexParams,
-    progress_step=(Optional[int], Field(default=None, ge=0, le=100,
+    progress_step=(Optional[int], Field(default=5, ge=0, le=100,
                          description="Optional step size for progress reporting during indexing")),
     clean_index=(Optional[bool], Field(default=False,
                        description="Optional flag to enforce clean existing index before indexing new data")),
-    chunking_tool=(Literal['','markdown', 'statistical', 'proposal'], Field(description="Name of chunking tool", default=None)),
+    chunking_tool=(Literal[None,'markdown', 'statistical', 'proposal'], Field(description="Name of chunking tool", default=None)),
     chunking_config=(Optional[dict], Field(description="Chunking tool configuration", default_factory=dict)),
 )
 
@@ -124,6 +125,28 @@ class BaseToolApiWrapper(BaseModel):
     def get_available_tools(self):
         raise NotImplementedError("Subclasses should implement this method")
 
+    def _log_tool_event(self, message: str, tool_name: str = None):
+        """Log data and dispatch custom event for the tool"""
+
+        try:
+            from langchain_core.callbacks import dispatch_custom_event
+
+            if tool_name is None:
+                tool_name = 'tool_progress'
+
+            logger.info(message)
+            dispatch_custom_event(
+                name="thinking_step",
+                data={
+                    "message": message,
+                    "tool_name": tool_name,
+                    "toolkit": self.__class__.__name__,
+                },
+            )
+        except Exception as e:
+            logger.warning(f"Failed to dispatch progress event: {str(e)}")
+
+
     def run(self, mode: str, *args: Any, **kwargs: Any):
         if TOOLKIT_SPLITTER in mode:
             mode = mode.rsplit(TOOLKIT_SPLITTER, maxsplit=1)[1]
@@ -217,6 +240,15 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
     embedding_model: Optional[str] = "HuggingFaceEmbeddings"
     embedding_model_params: Optional[Dict[str, Any]] = {"model_name": "sentence-transformers/all-MiniLM-L6-v2"}
     vectorstore_type: Optional[str] = "PGVector"
+    _vector_store: Optional[Any] = None
+    _embedding: Optional[Any] = None
+    alita: Any = None # Elitea client, if available
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self._adapter = VectorStoreAdapterFactory.create_adapter(self.vectorstore_type)
+        if self.alita and self.embedding_model:
+            self._embedding = self.alita.get_embeddings(self.embedding_model)
 
     def _index_tool_params(self, **kwargs) -> dict[str, tuple[type, Field]]:
         """
@@ -229,9 +261,7 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
         return markdown_chunker
 
     def _get_dependencies_chunker_config(self, document: Optional[Document] = None):
-        embedding = get_embeddings(self.embedding_model, self.embedding_model_params)
-        #
-        return {'embedding': embedding, 'llm': self.llm}
+        return {'embedding': self._embedding, 'llm': self.llm}
 
     def _base_loader(self, **kwargs) -> Generator[Document, None, None]:
         """ Loads documents from a source, processes them,
@@ -265,7 +295,6 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
     def index_data(self, **kwargs):
         from alita_sdk.tools.chunkers import __confluence_chunkers__ as chunkers, __confluence_models__ as models
         docs = self._base_loader(**kwargs)
-        embedding = get_embeddings(self.embedding_model, self.embedding_model_params)
         chunking_tool = kwargs.get("chunking_tool")
         if chunking_tool:
             # Resolve chunker from the provided chunking_tool name
@@ -274,7 +303,7 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
             base_chunking_config = kwargs.get("chunking_config", {})
             config_model = models.get(chunking_tool)
             # Set required fields that should come from the instance (and Fallback for chunkers without models)
-            base_chunking_config['embedding'] = embedding
+            base_chunking_config['embedding'] = self._embedding
             base_chunking_config['llm'] = self.llm
             #
             if config_model:
@@ -291,9 +320,9 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
         collection_suffix = kwargs.get("collection_suffix")
         progress_step = kwargs.get("progress_step")
         clean_index = kwargs.get("clean_index")
-        vs = self._init_vector_store(collection_suffix, embeddings=embedding)
+        vs = self._init_vector_store()
         #
-        return vs.index_documents(docs, progress_step=progress_step, clean_index=clean_index)
+        return vs.index_documents(docs, collection_suffix=collection_suffix, progress_step=progress_step, clean_index=clean_index)
 
     def _process_documents(self, documents: List[Document]) -> Generator[Document, None, None]:
         """
@@ -308,7 +337,13 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
         Returns:
             Generator[Document, None, None]: A generator yielding processed documents with metadata.
         """
-        for doc in documents:
+        total_docs = len(documents)
+        self._log_tool_event(
+            message=f"Preparing a base documents for indexing. Total documents: {total_docs}",
+            tool_name="_process_documents"
+        )
+        processed_count = 0
+        for idx, doc in enumerate(documents, 1):
             # Filter documents to process only those that either:
             # - do not have a 'chunk_id' in their metadata, or
             # - have 'chunk_id' explicitly set to 1.
@@ -320,60 +355,63 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
                     for processed_doc in processed_docs:
                         # map processed document (child) to the original document (parent)
                         processed_doc.metadata[IndexerKeywords.PARENT.value] = doc.metadata.get('id', None)
-                        if chunker:=self._get_dependencies_chunker(processed_doc):
-                            yield from chunker(file_content_generator=iter([processed_doc]), config=self._get_dependencies_chunker_config())
+                        if chunker := self._get_dependencies_chunker(processed_doc):
+                            yield from chunker(
+                                file_content_generator=iter([processed_doc]),
+                                config=self._get_dependencies_chunker_config()
+                            )
                         else:
                             yield processed_doc
+                processed_count += 1
+                if processed_count % 5 == 0 or processed_count == total_docs:
+                    self._log_tool_event(
+                        message=f"Prepared {processed_count} out of {total_docs} documents for indexing.",
+                        tool_name="_process_documents"
+                    )
 
 
-    def _init_vector_store(self, collection_suffix: str = "", embeddings: Optional[Any] = None):
-        """ Initializes the vector store wrapper with the provided parameters."""
+    # TODO: init store once and re-use the instance
+    def _init_vector_store(self):
+        """Initializes the vector store wrapper with the provided parameters."""
         try:
             from alita_sdk.runtime.tools.vectorstore import VectorStoreWrapper
         except ImportError:
             from alita_sdk.runtime.tools.vectorstore import VectorStoreWrapper
-        
-        # Validate collection_suffix length
-        if collection_suffix and len(collection_suffix.strip()) > 7:
-            raise ToolException("collection_suffix must be 7 characters or less")
-        
-        # Create collection name with suffix if provided
-        collection_name = str(self.collection_name)
-        if collection_suffix and collection_suffix.strip():
-            collection_name = f"{self.collection_name}_{collection_suffix.strip()}"
-        
-        if self.vectorstore_type == 'PGVector':
-            vectorstore_params = {
-                "use_jsonb": True,
-                "collection_name": collection_name,
-                "create_extension": True,
-                "alita_sdk_options": {
-                    "target_schema": collection_name,
-                },
-                "connection_string": self.connection_string.get_secret_value()
-            }
-        elif self.vectorstore_type == 'Chroma':
-            vectorstore_params = {
-                "collection_name": collection_name,
-                "persist_directory": "./indexer_db"
-            }
 
-        return VectorStoreWrapper(
-            llm=self.llm,
-            vectorstore_type=self.vectorstore_type,
-            embedding_model=self.embedding_model,
-            embedding_model_params=self.embedding_model_params,
-            vectorstore_params=vectorstore_params,
-            embeddings=embeddings,
-            process_document_func=self._process_documents,
-        )
+        if not self._vector_store:
+            connection_string = self.connection_string.get_secret_value() if self.connection_string else None
+            vectorstore_params = self._adapter.get_vectorstore_params(self.collection_name, connection_string)
+            self._vector_store = VectorStoreWrapper(
+                llm=self.llm,
+                vectorstore_type=self.vectorstore_type,
+                embedding_model=self.embedding_model,
+                embedding_model_params=self.embedding_model_params,
+                vectorstore_params=vectorstore_params,
+                embeddings=self._embedding,
+                process_document_func=self._process_documents,
+            )
+        return self._vector_store
 
     def remove_index(self, collection_suffix: str = ""):
-        """
-            Cleans the indexed data in the collection
-        """
+        """Cleans the indexed data in the collection."""
+        self._init_vector_store()._clean_collection(collection_suffix=collection_suffix)
+        return (f"Collection '{collection_suffix}' has been removed from the vector store.\n"
+                f"Available collections: {self.list_collections()}")
 
-        self._init_vector_store(collection_suffix)._clean_collection()
+    def list_collections(self):
+        """Lists all collections in the vector store."""
+        vectorstore_wrapper = self._init_vector_store()
+        return vectorstore_wrapper.list_collections()
+
+    def _build_collection_filter(self, filter: dict | str, collection_suffix: str = "") -> dict:
+        """Builds a filter for the collection based on the provided suffix."""
+
+        filter = filter if isinstance(filter, dict) else json.loads(filter)
+        if collection_suffix:
+            filter.update({"collection": {
+                "$eq": collection_suffix.strip()
+            }})
+        return filter
 
     def search_index(self,
                      query: str,
@@ -385,18 +423,20 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
                      extended_search: Optional[List[str]] = None,
                      **kwargs):
         """ Searches indexed documents in the vector store."""
-        vectorstore = self._init_vector_store(collection_suffix)
-        return vectorstore.search_documents(
-            query, 
-            doctype=self.doctype, 
-            filter=filter, 
-            cut_off=cut_off, 
-            search_top=search_top, 
+        vectorstore = self._init_vector_store()
+        filter = self._build_collection_filter(filter, collection_suffix)
+        found_docs = vectorstore.search_documents(
+            query,
+            doctype=self.doctype,
+            filter=filter,
+            cut_off=cut_off,
+            search_top=search_top,
             reranker=reranker,
-            full_text_search=full_text_search, 
-            reranking_config=reranking_config, 
+            full_text_search=full_text_search,
+            reranking_config=reranking_config,
             extended_search=extended_search
         )
+        return found_docs if found_docs else f"No documents found by query '{query}' and filter '{filter}'"
 
     def stepback_search_index(self,
                      query: str,
@@ -409,18 +449,21 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
                      extended_search: Optional[List[str]] = None,
                      **kwargs):
         """ Searches indexed documents in the vector store."""
-        vectorstore = self._init_vector_store(collection_suffix)
-        return vectorstore.stepback_search(
-            query, 
-            messages, 
-            self.doctype, 
-            filter=filter, 
-            cut_off=cut_off, 
+
+        filter = self._build_collection_filter(filter, collection_suffix)
+        vectorstore = self._init_vector_store()
+        found_docs = vectorstore.stepback_search(
+            query,
+            messages,
+            self.doctype,
+            filter=filter,
+            cut_off=cut_off,
             search_top=search_top,
-            full_text_search=full_text_search, 
-            reranking_config=reranking_config, 
+            full_text_search=full_text_search,
+            reranking_config=reranking_config,
             extended_search=extended_search
         )
+        return found_docs if found_docs else f"No documents found by query '{query}' and filter '{filter}'"
 
     def stepback_summary_index(self,
                      query: str,
@@ -433,18 +476,21 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
                      extended_search: Optional[List[str]] = None,
                      **kwargs):
         """ Generates a summary of indexed documents using stepback technique."""
-        vectorstore = self._init_vector_store(collection_suffix)
-        return vectorstore.stepback_summary(
-            query, 
-            messages, 
-            self.doctype, 
-            filter=filter, 
-            cut_off=cut_off, 
+        vectorstore = self._init_vector_store()
+        filter = self._build_collection_filter(filter, collection_suffix)
+
+        found_docs = vectorstore.stepback_summary(
+            query,
+            messages,
+            self.doctype,
+            filter=filter,
+            cut_off=cut_off,
             search_top=search_top,
-            full_text_search=full_text_search, 
-            reranking_config=reranking_config, 
+            full_text_search=full_text_search,
+            reranking_config=reranking_config,
             extended_search=extended_search
         )
+        return found_docs if found_docs else f"No documents found by query '{query}' and filter '{filter}'"
 
     def _get_vector_search_tools(self):
         """
@@ -483,11 +529,21 @@ class BaseVectorStoreToolApiWrapper(BaseToolApiWrapper):
                 "description": self.remove_index.__doc__,
                 "args_schema": RemoveIndexParams
             },
+            {
+                "name": "list_collections",
+                "mode": "list_collections",
+                "ref": self.list_collections,
+                "description": self.list_collections.__doc__,
+                "args_schema": create_model("ListCollectionsParams")  # No parameters
+            },
+
         ]
 
 
 class BaseCodeToolApiWrapper(BaseVectorStoreToolApiWrapper):
 
+    doctype: Optional[str] = 'code'
+
     def _get_files(self):
         raise NotImplementedError("Subclasses should implement this method")
 
@@ -544,46 +600,59 @@ class BaseCodeToolApiWrapper(BaseVectorStoreToolApiWrapper):
         """
         from .chunkers.code.codeparser import parse_code_files_for_db
 
-        _files = self.__handle_get_files("", branch or self.active_branch)
-
+        _files = self.__handle_get_files("", branch or self.active_branch or self._active_branch)
+        self._log_tool_event(message="Listing files in branch", tool_name="loader")
         logger.info(f"Files in branch: {_files}")
 
         def is_whitelisted(file_path: str) -> bool:
             if whitelist:
-                return any(fnmatch.fnmatch(file_path, pattern) for pattern in whitelist)
+                return (any(fnmatch.fnmatch(file_path, pattern) for pattern in whitelist)
+                        or any(file_path.endswith(f'.{pattern}') for pattern in whitelist))
             return True
 
         def is_blacklisted(file_path: str) -> bool:
             if blacklist:
-                return any(fnmatch.fnmatch(file_path, pattern) for pattern in blacklist)
+                return (any(fnmatch.fnmatch(file_path, pattern) for pattern in blacklist)
+                        or any(file_path.endswith(f'.{pattern}') for pattern in blacklist))
             return False
 
         def file_content_generator():
-            for file in _files:
+            self._log_tool_event(message="Reading the files", tool_name="loader")
+            # log the progress of file reading
+            total_files = len(_files)
+            for idx, file in enumerate(_files, 1):
                 if is_whitelisted(file) and not is_blacklisted(file):
+                    # read file ONLY if it matches whitelist and does not match blacklist
+                    file_content = self._read_file(file, branch=branch or self.active_branch or self._active_branch)
+                    # hash the file content to ensure uniqueness
+                    import hashlib
+                    file_hash = hashlib.sha256(file_content.encode("utf-8")).hexdigest()
                     yield {"file_name": file,
-                           "file_content": self._read_file(file, branch=branch or self.active_branch),
-                           "commit_hash": self._file_commit_hash(file, branch=branch or self.active_branch)}
+                           "file_content": file_content,
+                           "commit_hash": file_hash}
+                if idx % 10 == 0 or idx == total_files:
+                    self._log_tool_event(message=f"{idx} out of {total_files} files have been read", tool_name="loader")
+            self._log_tool_event(message=f"{len(_files)} have been read", tool_name="loader")
 
         return parse_code_files_for_db(file_content_generator())
     
     def index_data(self,
+                   collection_suffix: str,
                    branch: Optional[str] = None,
                    whitelist: Optional[List[str]] = None,
                    blacklist: Optional[List[str]] = None,
-                   collection_suffix: str = "",
                    **kwargs) -> str:
         """Index repository files in the vector store using code parsing."""
         
-        
-        
         documents = self.loader(
             branch=branch,
             whitelist=whitelist,
             blacklist=blacklist
         )
-        vectorstore = self._init_vector_store(collection_suffix)
-        return vectorstore.index_documents(documents, clean_index=False, is_code=True)
+        vectorstore = self._init_vector_store()
+        clean_index = kwargs.get('clean_index', False)
+        return vectorstore.index_documents(documents, collection_suffix=collection_suffix,
+                                           clean_index=clean_index, is_code=True)
 
     def _get_vector_search_tools(self):
         """
