@@ -1,11 +1,13 @@
 from typing import List, Literal, Optional
 
 from langchain_core.tools import BaseTool, BaseToolkit
-from pydantic import BaseModel, ConfigDict, Field, create_model, SecretStr
+from pydantic import BaseModel, ConfigDict, Field, create_model
 
 from ..base.tool import BaseAction
 from .api_wrapper import FigmaApiWrapper, GLOBAL_LIMIT
 from ..utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length
+from ...configurations.figma import FigmaConfiguration
+from ...configurations.pgvector import PgVectorConfiguration
 
 name = "figma"
 
@@ -14,18 +16,17 @@ def get_tools(tool):
         FigmaToolkit()
         .get_toolkit(
             selected_tools=tool["settings"].get("selected_tools", []),
-            token=tool["settings"].get("token", None),
-            oauth2=tool["settings"].get("oauth2", None),
+            figma_configuration=tool['settings']['figma_configuration'],
             global_limit=tool["settings"].get("global_limit", GLOBAL_LIMIT),
             global_regexp=tool["settings"].get("global_regexp", None),
             toolkit_name=tool.get('toolkit_name'),
             # indexer settings
             llm=tool['settings'].get('llm', None),
-            connection_string = tool['settings'].get('connection_string', None),
-            collection_name=str(tool['id']),
+            alita=tool['settings'].get('alita', None),
+            pgvector_configuration=tool['settings'].get('pgvector_configuration', {}),
+            collection_name=str(tool['toolkit_name']),
             doctype='doc',
-            embedding_model="HuggingFaceEmbeddings",
-            embedding_model_params={"model_name": "sentence-transformers/all-MiniLM-L6-v2"},
+            embedding_model=tool['settings'].get('embedding_model'),
             vectorstore_type="PGVector"
         )
         .get_tools()
@@ -45,39 +46,26 @@ class FigmaToolkit(BaseToolkit):
         FigmaToolkit.toolkit_max_length = get_max_toolkit_length(selected_tools)
         return create_model(
             name,
-            token=(Optional[SecretStr], Field(description="Figma Token", json_schema_extra={"secret": True}, default=None)),
-            oauth2=(Optional[SecretStr], Field(description="OAuth2 Token", json_schema_extra={"secret": True}, default=None)),
             global_limit=(Optional[int], Field(description="Global limit", default=GLOBAL_LIMIT)),
             global_regexp=(Optional[str], Field(description="Global regex pattern", default=None)),
             selected_tools=(
                 List[Literal[tuple(selected_tools)]],
                 Field(default=[], json_schema_extra={"args_schemas": selected_tools}),
             ),
+            # Figma configuration
+            figma_configuration=(Optional[FigmaConfiguration], Field(description="Figma configuration", json_schema_extra={'configuration_types': ['figma']})),
+
             # indexer settings
-            connection_string = (Optional[SecretStr], Field(description="Connection string for vectorstore",
-                                                            default=None,
-                                                            json_schema_extra={'secret': True})),
+            pgvector_configuration=(Optional[PgVectorConfiguration], Field(description="PgVector Configuration", json_schema_extra={'configuration_types': ['pgvector']})),
+
+            # embedder settings
+            embedding_model=(Optional[str], Field(default=None, description="Embedding configuration.", json_schema_extra={'configuration_model': 'embedding'})),
             __config__=ConfigDict(
                 json_schema_extra={
                      "metadata": {
                          "label": "Figma",
                          "icon_url": "figma-icon.svg",
                          "max_length": FigmaToolkit.toolkit_max_length,
-                         "sections": {
-                             "auth": {
-                                 "required": True,
-                                 "subsections": [
-                                     {
-                                         "name": "Token",
-                                         "fields": ["token"]
-                                     },
-                                     {
-                                         "name": "Oath2",
-                                         "fields": ["oauth2"]
-                                     }
-                                 ]
-                             }
-                         },
                          "categories": ["other"],
                          "extra_categories": ["figma", "design", "ui/ux", "prototyping", "collaboration"],
                      }
@@ -89,7 +77,12 @@ class FigmaToolkit(BaseToolkit):
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
-        figma_api_wrapper = FigmaApiWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            **kwargs.get('figma_configuration'),
+            **(kwargs.get('pgvector_configuration') or {}),
+        }
+        figma_api_wrapper = FigmaApiWrapper(**wrapper_payload)
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
         available_tools = figma_api_wrapper.get_available_tools()
         tools = []
