@@ -7,6 +7,7 @@ from pydantic import create_model, BaseModel, ConfigDict, Field, SecretStr
 from .api_wrapper import QtestApiWrapper
 from .tool import QtestAction
 from ..utils import clean_string, get_max_toolkit_length, TOOLKIT_SPLITTER, check_connection_response
+from ...configurations.qtest import QtestConfiguration
 
 name = "qtest"
 
@@ -16,7 +17,7 @@ def get_tools(tool):
         selected_tools=tool['settings'].get('selected_tools', []),
         base_url=tool['settings'].get('base_url', None),
         qtest_project_id=tool['settings'].get('qtest_project_id', tool['settings'].get('project_id', None)),
-        qtest_api_token=tool['settings'].get('qtest_api_token', None),
+        qtest_configuration=tool['settings']['qtest_configuration'],
         toolkit_name=tool.get('toolkit_name')
     )
     return toolkit.tools
@@ -32,13 +33,17 @@ class QtestToolkit(BaseToolkit):
         QtestToolkit.toolkit_max_length = get_max_toolkit_length(selected_tools)
         m = create_model(
             name,
-            base_url=(str, Field(description="QTest base url", json_schema_extra={'configuration': True, 'configuration_title': True})),
-            qtest_project_id=(int, Field(description="QTest project id", json_schema_extra={'toolkit_name': True, 'max_toolkit_length': QtestToolkit.toolkit_max_length})),
-            qtest_api_token=(SecretStr, Field(description="QTest API token", json_schema_extra={'secret': True, 'configuration': True})),
-            selected_tools=(List[Literal[tuple(selected_tools)]], Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
+            qtest_configuration=(Optional[QtestConfiguration], Field(description="QTest API token", json_schema_extra={
+                'configuration_types': ['qtest']})),
+            qtest_project_id=(int, Field(default=None, description="QTest project id", json_schema_extra={'toolkit_name': True,
+                                                                                            'max_toolkit_length': QtestToolkit.toolkit_max_length})),
+            selected_tools=(List[Literal[tuple(selected_tools)]],
+                            Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             __config__=ConfigDict(json_schema_extra={'metadata': {"label": "QTest", "icon_url": "qtest.svg",
                                                                   "categories": ["test management"],
-                                                                  "extra_categories": ["quality assurance", "test case management", "test planning"]}})
+                                                                  "extra_categories": ["quality assurance",
+                                                                                       "test case management",
+                                                                                       "test planning"]}})
         )
 
         @check_connection_response
@@ -59,7 +64,12 @@ class QtestToolkit(BaseToolkit):
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
-        qtest_api_wrapper = QtestApiWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # TODO use qtest_configuration fields
+            **kwargs['qtest_configuration'],
+        }
+        qtest_api_wrapper = QtestApiWrapper(**wrapper_payload)
         prefix = clean_string(str(toolkit_name), cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
         available_tools = qtest_api_wrapper.get_available_tools()
         tools = []
