@@ -1,11 +1,13 @@
-from pathlib import Path
-
-from langchain_core.tools import ToolException
+import os
+import tempfile
 from logging import getLogger
-from alita_sdk.runtime.langchain.document_loaders.constants import loaders_map
-from langchain_core.documents import Document
+from pathlib import Path
+from typing import Generator
 
-from ...runtime.langchain.document_loaders.utils import create_temp_file
+from langchain_core.documents import Document
+from langchain_core.tools import ToolException
+
+from alita_sdk.runtime.langchain.document_loaders.constants import loaders_map
 
 logger = getLogger(__name__)
 
@@ -77,6 +79,10 @@ def parse_file_content(file_name=None, file_content=None, is_capture_image: bool
     extension = Path(file_path if file_path else file_name).suffix
 
     loader_object = loaders_map.get(extension)
+    if not loader_object:
+        logger.warning(f"No loader found for file extension: {extension}. File: {file_path if file_path else file_name}")
+        return ToolException(
+            "Not supported type of files entered. Supported types are TXT, DOCX, PDF, PPTX, XLSX and XLS only.")
     loader_kwargs = loader_object['kwargs']
     loader_kwargs.update({
         "file_path": file_path,
@@ -86,7 +92,9 @@ def parse_file_content(file_name=None, file_content=None, is_capture_image: bool
         "llm": llm,
         "page_number": page_number,
         "sheet_name": sheet_name,
-        "excel_by_sheets": excel_by_sheets
+        "excel_by_sheets": excel_by_sheets,
+        "row_content": True,
+        "json_documents": False
     })
     loader = loader_object['class'](**loader_kwargs)
 
@@ -131,8 +139,10 @@ def load_content(file_path: str, extension: str = None, loader_extra_config: dic
             loader_kwargs.update(loader_extra_config)
         if loader_config['is_multimodal_processing'] and llm:
             loader_kwargs.update({'llm': llm})
+        if "file_path" in loader_kwargs:
+            del loader_kwargs["file_path"]
 
-        loader = loader_cls(file_path, **loader_kwargs)
+        loader = loader_cls(file_path=file_path, **loader_kwargs)
         documents = loader.load()
 
         page_contents = [doc.page_content for doc in documents]
@@ -143,26 +153,69 @@ def load_content(file_path: str, extension: str = None, loader_extra_config: dic
         return ""
 
 def load_content_from_bytes(file_content: bytes, extension: str = None, loader_extra_config: dict = None, llm = None) -> str:
-    """Loads the content of a file from bytes based on its extension using a configured loader."""
-    return load_content(create_temp_file(file_content), extension, loader_extra_config, llm)
-
-def file_to_bytes(filepath):
-    """
-    Reads a file and returns its content as a bytes object.
-
-    Args:
-        filepath (str): The path to the file.
-
-    Returns:
-        bytes: The content of the file as a bytes object.
-    """
+    temp_file_path = None
     try:
-        with open(filepath, "rb") as f:
-            file_content_bytes = f.read()
-        return file_content_bytes
-    except FileNotFoundError:
-        logger.error(f"File not found: {filepath}")
-        return None
-    except Exception as e:
-        logger.error(f"Error reading file {filepath}: {e}")
-        return None
\ No newline at end of file
+        with tempfile.NamedTemporaryFile(mode='w+b', delete=False) as temp_file:
+            temp_file.write(file_content)
+            temp_file.flush()
+            temp_file_path = temp_file.name
+
+        # Now the file is closed and can be read
+        result = load_content(temp_file_path, extension, loader_extra_config, llm)
+        return result
+    finally:
+        if temp_file_path and os.path.exists(temp_file_path):
+            os.remove(temp_file_path)
+
+def process_content_by_type(document: Document, content, extension_source: str, llm = None, chunking_config={}) -> Generator[Document, None, None]:
+    temp_file_path = None
+    try:
+        extension = "." + extension_source.split('.')[-1].lower()
+
+        with tempfile.NamedTemporaryFile(mode='w+b', suffix=extension, delete=False) as temp_file:
+            temp_file_path = temp_file.name
+            if content is None:
+                logger.warning("'loader_content' ie expected but not found in document metadata.")
+                return
+            
+            temp_file.write(content)
+            temp_file.flush()
+
+            loader_config = loaders_map.get(extension)
+            if not loader_config:
+                logger.warning(f"No loader found for file extension: {extension}. File: {temp_file_path}")
+                return
+
+            loader_cls = loader_config['class']
+            loader_kwargs = loader_config['kwargs']
+
+            loader = loader_cls(file_path=temp_file_path, **loader_kwargs)
+            for chunk in loader.load():
+                yield Document(
+                    page_content=sanitize_for_postgres(chunk.page_content),
+                    metadata={**document.metadata, **chunk.metadata}
+                )
+    finally:
+        if temp_file_path and os.path.exists(temp_file_path):
+            os.remove(temp_file_path)
+
+# FIXME copied from langchain_core/utils/strings.py of 0.3.74 version
+# https://github.com/langchain-ai/langchain/pull/32157
+# should be used from langchain_core.utils import sanitize_for_postgres once updated to newer version
+def sanitize_for_postgres(text: str, replacement: str = "") -> str:
+    r"""Sanitize text by removing NUL bytes that are incompatible with PostgreSQL.
+    PostgreSQL text fields cannot contain NUL (0x00) bytes, which can cause
+    psycopg.DataError when inserting documents. This function removes or replaces
+    such characters to ensure compatibility.
+    Args:
+        text: The text to sanitize.
+        replacement: String to replace NUL bytes with. Defaults to empty string.
+    Returns:
+        str: The sanitized text with NUL bytes removed or replaced.
+    Example:
+        >>> sanitize_for_postgres("Hello\\x00world")
+        'Helloworld'
+        >>> sanitize_for_postgres("Hello\\x00world", " ")
+        'Hello world'
+    """
+    return text.replace("\x00", replacement)
\ No newline at end of file
